@@ -943,7 +943,6 @@ class TestPagination(object):
     def test_generate(self):
         iter, status, heaaders = self.c.open()
         s = ''.join(iter)
-        print s
         assert s == """
 <a href="/?page=2">&laquo; Prev</a> <a href="/?page=1">1</a><span class="commata">,
 </span><a href="/?page=2">2</a><span class="commata">,
@@ -954,6 +953,124 @@ class TestPagination(object):
 </span><a href="/?page=50">50</a> <a href="/?page=4">Next &raquo;</a>
 """.strip()
 
+
+#sqla
+
+from glashammer.bundles.sqladb import setup_sqladb, db, metadata, \
+    JsonSqlaRestService
+
+class TestSQLA(object):
+
+    def setup(self):
+        if os.path.exists('test_output/gh.sqlite'):
+            os.unlink('test_output/gh.sqlite')
+
+
+        metadata.drop_all()
+
+
+        # The SQLA tables
+        notes = db.Table('notes', metadata,
+            db.Column('id', db.Integer, primary_key=True),
+            db.Column('title', db.Text),
+            db.Column('note', db.Text),
+            db.Column('importance', db.Text),
+            useexisting=True,
+        )
+
+        # The ORM mapped class
+        class Note(object):
+            """ Represents a note """
+
+        self.Note = Note
+
+        # Make a mapper which gives you the objects manager
+        db.mapper(Note, notes)
+
+
+        class NotesService(JsonSqlaRestService):
+
+            def get_table(self):
+                return Note
+
+        def setup_db(app):
+            #metadata.create_all(app.sqla_db_engine)
+            #print metadata.tables
+            #print dir(notes)
+            notes.create(app.sqla_db_engine)
+
+        def setup_app(app):
+            app.add_setup(setup_sqladb)
+            app.add_data_func(setup_db)
+            app.add_url('/notes', 'notes/svc', view=NotesService())
+
+        self.app = make_app(setup_app, 'test_output')
+        self.c = Client(self.app)
+
+    def test_engine(self):
+        assert get_app().sqla_db_engine
+
+    def test_objects(self):
+        assert self.Note.objects.count() == 0
+        for t in 'abcdef':
+            n = self.Note()
+            n.title = n.note = n.importance = t
+        db.commit()
+        assert self.Note.objects.count() == 6
+
+    def test_rest_get(self):
+        for t in 'abcdef':
+            n = self.Note()
+            n.title = n.note = n.importance = t
+        db.commit()
+        iter, status, header = self.c.open('/notes')
+        resp = loads(''.join(iter))
+        res = resp['results']
+        assert resp['total'] == 6
+        for i, l in enumerate('abcdef'):
+            assert res[i]['title'] == l
+            assert res[i]['note'] == l
+            assert res[i]['importance'] == l
+            assert res[i]['id'] == (i + 1)
+
+    def test_rest_post(self):
+        for t in 'abcdef':
+            n = self.Note()
+            n.title = n.note = n.importance = t
+        db.commit()
+        iter, status, header = self.c.post('/notes',
+            data={
+                'title': 'g',
+                'note': 'g',
+                'importance':'g'
+            }
+        )
+        resp = loads(''.join(iter))
+        res = resp['results']
+        assert resp['total'] == 1
+        assert resp['results'][0]['title'] == 'g'
+        assert resp['results'][0]['note'] == 'g'
+        assert resp['results'][0]['importance'] == 'g'
+        assert resp['results'][0]['id'] > 0
+
+
+# openid
+
+def test_openid():
+
+    def setup_openid(app):
+        from glashammer.bundles.openidauth import setup_openid
+        app.add_setup(setup_openid)
+
+    app = make_app(setup_openid, 'test_output')
+
+    c = Client(app)
+    iter, status, headers = c.post('/openid/login',
+        data={'openid':'http://unpythonic.blogspot.com'})
+
+    assert '302' in status
+
+
 # functional tests for examples
 
 from glashammer.utils.system import load_app_from_path
@@ -1024,3 +1141,4 @@ class TestJsonRest(object):
         assert d['type'] == 'POST'
 
 
+
